@@ -1,6 +1,8 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 'Address'
+from sql import Null
+
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import Eval, If
 from trytond.transaction import Transaction
@@ -61,7 +63,7 @@ class Address(ModelSQL, ModelView):
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
-        return [table.sequence == None, table.sequence]
+        return [table.sequence == Null, table.sequence]
 
     @staticmethod
     def default_active():
@@ -141,7 +143,11 @@ class Address(ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return ['OR',
+        if clause[1].startswith('!') or clause[1].startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
+        return [bool_op,
             ('zip',) + tuple(clause[1:]),
             ('city',) + tuple(clause[1:]),
             ('name',) + tuple(clause[1:]),
@@ -155,12 +161,12 @@ class Address(ModelSQL, ModelView):
             if 'party' in values:
                 for address in addresses:
                     if address.party.id != values['party']:
-                        cls.raise_user_error('write_party', (address.rec_name,))
+                        cls.raise_user_error(
+                            'write_party', (address.rec_name,))
         super(Address, cls).write(*args)
 
     @fields.depends('subdivision', 'country')
     def on_change_country(self):
         if (self.subdivision
                 and self.subdivision.country != self.country):
-            return {'subdivision': None}
-        return {}
+            self.subdivision = None
