@@ -1,5 +1,7 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
+from sql import Null
+
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
@@ -102,7 +104,7 @@ class ContactMechanism(ModelSQL, ModelView):
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
-        return [table.sequence == None, table.sequence]
+        return [table.sequence == Null, table.sequence]
 
     @staticmethod
     def default_type():
@@ -132,26 +134,21 @@ class ContactMechanism(ModelSQL, ModelView):
 
     @classmethod
     def set_value(cls, mechanisms, name, value):
-        cls.write(mechanisms, {
-            'value': value,
-            })
+        #  Setting value is done by on_changes
+        pass
 
     def _change_value(self, value):
-        return {
-            'value': value,
-            'website': value,
-            'email': value,
-            'skype': value,
-            'sip': value,
-            'other_value': value,
-            'url': self.get_url(value=value)
-            }
+        self.value = value
+        self.website = value
+        self.email = value
+        self.skype = value
+        self.sip = value
+        self.other_value = value
+        self.url = self.get_url(value=value)
 
     @fields.depends('value', 'type')
     def on_change_type(self):
-        return {
-            'url': self.get_url(value=self.value),
-            }
+        self.url = self.get_url(value=self.value)
 
     @fields.depends('value', 'type')
     def on_change_value(self):
@@ -184,5 +181,6 @@ class ContactMechanism(ModelSQL, ModelView):
             if 'party' in values:
                 for mechanism in mechanisms:
                     if mechanism.party.id != values['party']:
-                        cls.raise_user_error('write_party', (mechanism.rec_name,))
+                        cls.raise_user_error(
+                            'write_party', (mechanism.rec_name,))
         super(ContactMechanism, cls).write(*args)
